==> hyperkyc_flutter-0.3.0.tar.gz: android/src/main/java/co/hyperverge/hyperkyc_flutter/FLHyperKyc.java <==
package co.hyperverge.hyperkyc_flutter;

import java.util.Map;

import co.hyperverge.hyperkyc.data.models.HyperKycConfig;

public class FLHyperKyc {
    private static final String TAG = FLHyperKyc.class.getCanonicalName();

    private static final String APP_ID = "appId";
    private static final String APP_KEY = "appKey";
    private static final String ACCESS_TOKEN = "accessToken";
    private static final String WORKFLOW_ID = "workflowId";
    private static final String TRANSACTION_ID = "transactionId";
    private static final String INPUTS = "inputs";
    private static final String DEFAULT_LANG_CODE = "defaultLangCode";

    public HyperKycConfig getHyperKycConfigFromMap(Map<String, Object> hyperKycConfigMap) {
        String appId = null;
        String appKey = null;
        String accessToken = null;
        String workflowId = null;
        String transactionId = null;
        Map<String, String> inputs = null;
        String defaultLangCode = null;
        if (hyperKycConfigMap.containsKey(APP_ID)) {
            appId = (String) hyperKycConfigMap.get(APP_ID);
        }
        if (hyperKycConfigMap.containsKey(APP_KEY)) {
            appKey = (String) hyperKycConfigMap.get(APP_KEY);
        }
        if (hyperKycConfigMap.containsKey(ACCESS_TOKEN)) {
            accessToken = (String) hyperKycConfigMap.get(ACCESS_TOKEN);
        }
        if (hyperKycConfigMap.containsKey(WORKFLOW_ID)) {
            workflowId = (String) hyperKycConfigMap.get(WORKFLOW_ID);
        }
        if (hyperKycConfigMap.containsKey(TRANSACTION_ID)) {
            transactionId = (String) hyperKycConfigMap.get(TRANSACTION_ID);
        }
        if (hyperKycConfigMap.containsKey(INPUTS)) {
            inputs = (Map<String, String>) hyperKycConfigMap.get(INPUTS);
        }
        if (hyperKycConfigMap.containsKey(DEFAULT_LANG_CODE)) {
            defaultLangCode = (String) hyperKycConfigMap.get(DEFAULT_LANG_CODE);
        }

        if (accessToken == null) {
            assert appId != null;
            assert appKey != null;
            assert workflowId != null;
            assert transactionId != null;
            HyperKycConfig hyperKycConfig = new HyperKycConfig(appId, appKey, workflowId, transactionId);
            if (inputs != null) {
                hyperKycConfig.setInputs(inputs);
            }
            if (defaultLangCode != null) {
                hyperKycConfig.setDefaultLangCode(defaultLangCode);
            }
            return hyperKycConfig;
        } else {
            assert workflowId != null;
            assert transactionId != null;
            HyperKycConfig hyperKycConfig = new HyperKycConfig(accessToken, workflowId, transactionId);
            if (inputs != null) {
                hyperKycConfig.setInputs(inputs);
            }
            if (defaultLangCode != null) {
                hyperKycConfig.setDefaultLangCode(defaultLangCode);
            }
            return hyperKycConfig;
        }
    }
}

==> hyperkyc_flutter-0.8.0.tar.gz: android/src/main/java/co/hyperverge/hyperkyc_flutter/FLHyperKyc.java <==
package co.hyperverge.hyperkyc_flutter;

import java.util.Map;

import co.hyperverge.hyperkyc.data.models.HyperKycConfig;

class FLHyperKyc {
    static final String TAG = FLHyperKyc.class.getCanonicalName();

    static final String APP_ID = "appId";
    static final String APP_KEY = "appKey";
    static final String ACCESS_TOKEN = "accessToken";
    static final String WORKFLOW_ID = "workflowId";
    static final String TRANSACTION_ID = "transactionId";
    static final String INPUTS = "inputs";
    static final String DEFAULT_LANG_CODE = "defaultLangCode";
    static final String METADATA = "metadata";

    public HyperKycConfig getHyperKycConfigFromMap(Map<String, Object> hyperKycConfigMap) {
        String appId = null;
        String appKey = null;
        String accessToken = null;
        String workflowId = null;
        String transactionId = null;
        Map<String, String> inputs = null;
        String defaultLangCode = null;
        Map<String, String> metadata = null;

        if (hyperKycConfigMap.containsKey(APP_ID)) {
            appId = (String) hyperKycConfigMap.get(APP_ID);
        }
        if (hyperKycConfigMap.containsKey(APP_KEY)) {
            appKey = (String) hyperKycConfigMap.get(APP_KEY);
        }
        if (hyperKycConfigMap.containsKey(ACCESS_TOKEN)) {
            accessToken = (String) hyperKycConfigMap.get(ACCESS_TOKEN);
        }
        if (hyperKycConfigMap.containsKey(WORKFLOW_ID)) {
            workflowId = (String) hyperKycConfigMap.get(WORKFLOW_ID);
        }
        if (hyperKycConfigMap.containsKey(TRANSACTION_ID)) {
            transactionId = (String) hyperKycConfigMap.get(TRANSACTION_ID);
        }
        if (hyperKycConfigMap.containsKey(INPUTS)) {
            inputs = (Map<String, String>) hyperKycConfigMap.get(INPUTS);
        }
        if (hyperKycConfigMap.containsKey(DEFAULT_LANG_CODE)) {
            defaultLangCode = (String) hyperKycConfigMap.get(DEFAULT_LANG_CODE);
        }
        if (hyperKycConfigMap.containsKey(METADATA)) {
            metadata = (Map<String, String>) hyperKycConfigMap.get(METADATA);
        }

        if (accessToken == null) {
            assert appId != null;
            assert appKey != null;
            assert workflowId != null;
            assert transactionId != null;
            HyperKycConfig hyperKycConfig = new HyperKycConfig(appId, appKey, workflowId, transactionId);
            if (inputs != null) {
                hyperKycConfig.setInputs(inputs);
            }
            if (defaultLangCode != null) {
                hyperKycConfig.setDefaultLangCode(defaultLangCode);
            }
            if (metadata != null) {
                hyperKycConfig.addMetadata(metadata);
            }
            return hyperKycConfig;
        } else {
            assert workflowId != null;
            assert transactionId != null;
            HyperKycConfig hyperKycConfig = new HyperKycConfig(accessToken, workflowId, transactionId);
            if (inputs != null) {
                hyperKycConfig.setInputs(inputs);
            }
            if (defaultLangCode != null) {
                hyperKycConfig.setDefaultLangCode(defaultLangCode);
            }
            if (metadata != null) {
                hyperKycConfig.addMetadata(metadata);
            }
            return hyperKycConfig;
        }
    }
}
